Crate mzdata_meta

Crate mzdata_meta 

Metadata describing mass spectrometry data files and their contents.

Macros

cvmap
delegate_impl_metadata_trait
Delegates the implementation of MSDataFileMetadata to a member. Passing an extra level extended token implements the optional methods.
impl_metadata_trait
Assumes a field for the non-Option facets of the MSDataFileMetadata implementation are present. Passing an extra level extended token implements the optional methods.

Structs

Component
A description of a combination of parts that are described as part of an InstrumentConfiguration. There may be more than one component of the same type in a singel configuration, e.g. a triple-quad instrument can have three separate ComponentType::Analyzer components.
DataProcessing
Describe a complete data processing method, a series of ProcessingMethod transformations through a pipeline of Software.
FileDescription
A description of the file data file and its contents
FileMetadataConfig
A helper data structure for implementing MSDataFileMetadata in a single common implementation.
InstrumentConfiguration
A series of mass spectrometer components that together were engaged to acquire a mass spectrum
MassSpectrometryRun
Metadata describing the experiment that does not belong in any other section that covers some default options.
NativeSpectrumIDFormat
A text-based schema that defines how native spectrum identifiers are formatted.
ProcessingMethod
Describe a data processing method stage tied to a specific piece of Software
Sample
A sample that was used to generate a MS dataset
ScanSettings
Description of the acquisition settings of the instrument prior to the start of the run
Software
A piece of software that was associated with the acquisition, transformation or otherwise processing of mass spectrometry data.
SoftwareTypeFlags
A bit mask encoding the different kinds of software.
SourceFile
Description of a source file, including location and type.
ValueType
A bit mask encoding the different value types a Param can take on, associated with a term.

Enums

ComponentType
A distinguishing tag describing the part of an instrument a Component refers to
DataProcessingAction
DataTransformationAction
DetectorTypeTerm
DissociationEnergy
DissociationEnergyTerm
Energy for an ion experiencing some form of dissociation
DissociationMethodTerm
A method used for dissociation or fragmentation.
FormatConversion
InletTypeTerm
IonizationTypeTerm
MassAnalyzerTerm
MassSpectrometerFileFormatTerm
NativeIDFormatError
NativeSpectrumIdentifierFormatTerm
A text-based schema that defines how native spectrum identifiers are formatted. These patterns are often found in mzML-compatible formats.
SoftwareTerm
SpectrumType
The kinds of spectrum that might be represented

Traits

MSDataFileMetadata
Mass spectrometry data files have several facets of descriptive metadata

Functions

custom_software_name
Create an instance of “custom unreleased software tool” with name name