DissociationEnergyTerm

Enum DissociationEnergyTerm 

pub enum DissociationEnergyTerm {
    CollisionEnergy(f32),
    NormalizedCollisionEnergy(f32),
    CollisionEnergyRampStart(f32),
    CollisionEnergyRampEnd(f32),
    PercentCollisionEnergyRampStart(f32),
    PercentCollisionEnergyRampEnd(f32),
    SupplementalCollisionEnergy(f32),
    ElectronBeamEnergy(f32),
}
Energy for an ion experiencing some form of dissociation

Variants



CollisionEnergy(f32)

collision energy - Energy for an ion experiencing collision with a stationary gas particle resulting in dissociation of the ion.



NormalizedCollisionEnergy(f32)

normalized collision energy - Instrument setting, expressed in percent, for adjusting collisional energies of ions in an effort to provide equivalent excitation of all ions.



CollisionEnergyRampStart(f32)

collision energy ramp start - Collision energy at the start of the collision energy ramp.



CollisionEnergyRampEnd(f32)

collision energy ramp end - Collision energy at the end of the collision energy ramp.



PercentCollisionEnergyRampStart(f32)

percent collision energy ramp start - Collision energy at the start of the collision energy ramp in percent, normalized to the mass of the ion.



PercentCollisionEnergyRampEnd(f32)

percent collision energy ramp end - Collision energy at the end of the collision energy ramp in percent, normalized to the mass of the ion.



SupplementalCollisionEnergy(f32)

supplemental collision energy - Energy for an ion experiencing supplemental collision with a stationary gas particle resulting in dissociation of the ion.



ElectronBeamEnergy(f32)

electron beam energy - The kinetic energy of the electron beam used in dissociation methods induced by a free electron beam, such as electron-capture dissociation (ECD), electron-detachment dissociation (EDD), and electron-activated dissociation (EAD).

Implementations

Source

impl DissociationEnergyTerm

These methods are part of the controlled vocabulary mapping

pub const fn accession(&self) -> AccessionIntCode

Retrieve the accession number for this term, independent of its controlled vocabulary

pub const fn controlled_vocabulary(&self) -> ControlledVocabulary

Retrieve the controlled vocabulary this term belongs to

pub const fn name(&self) -> &'static str

Retrieve the plain text human readable name for this term

pub fn from_name(name: &str) -> Option<Self>

Attempt to map a string by name to retrieve one of the terms from this set.

If no match is found, None is returned.

pub const fn from_accession( accession: AccessionIntCode, value: f32, ) -> Option<Self>

Attempt to map the numeric accession number to retrieve one of the terms from this set.

If no match is found, None is returned.

pub const fn to_param(self) -> ParamCow<'static>

Convert this term into a ParamCow without a value.

pub const fn to_param_value(self, value: ValueRef<'static>) -> ParamCow<'static>

Convert this term into a ParamCow a specific boxed value.

pub fn from_curie(curie: &CURIE, value: f32) -> Option<Self>

Convert a CURIE by accession.

If no match is found, None is returned.

pub fn from_param(p: &ParamCow<'static>) -> Option<Self>

Attempt to convert a ParamCow to a term from this set.

If no match is found, None is returned.

Note

This method can be called in const contexts, requiring the type be ParamCow with a 'static lifetime parameter, but the regular From trait is implemented for all ParamLike types.

pub fn flags(&self) -> i32

Retrieve a term set specific set of flags

pub fn parents(&self) -> Vec<Self>

Retrieve the list of zero or more terms in the set which are parents of this term.

Source

impl DissociationEnergyTerm

pub const fn is_supplemental(&self) -> bool

Is the collision energy supplemental to another dissociation method?

pub const fn is_ramp_start(&self) -> bool

Is this the start of an energy ramp?

pub const fn is_ramp_end(&self) -> bool

Is this the end of an energy ramp?

pub const fn energy(&self) -> f32

Get the scalar energy value for this term

pub fn energy_mut(&mut self) -> &mut f32

Get a mutable reference to the energy in the term