InstrumentConfiguration

Struct InstrumentConfiguration 

pub struct InstrumentConfiguration {
    pub components: Vec<Component>,
    pub params: ParamList,
    pub software_reference: String,
    pub id: u32,
}
A series of mass spectrometer components that together were engaged to acquire a mass spectrum

Fields

components: Vec<Component>

The set of components involved

params: ParamList

A set of parameters that describe the instrument such as the model name or serial number

software_reference: String

A reference to the data acquisition software involved in processing this configuration

id: u32

A unique identifier translated to an ordinal identifying this configuration

Implementations

Source

impl InstrumentConfiguration

pub fn new_component(&mut self, component_type: ComponentType) -> &mut Component

Add a new Component to the configuration, added at the end of the list

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn push(&mut self, value: Component)

Add a new Component to the end of the list, setting the Component::order field accordingly.

pub fn iter(&self) -> Iter<'_, Component>

pub fn last(&self) -> Option<&Component>

pub fn last_mut(&mut self) -> Option<&mut Component>