ProcessingMethod

Struct ProcessingMethod 

pub struct ProcessingMethod {
    pub order: i8,
    pub software_reference: String,
    pub params: ParamList,
}
Describe a data processing method stage tied to a specific piece of Software

See https://peptideatlas.org/tmp/mzML1.1.0.html#processingMethod

Fields

order: i8

The order of application of this method in the processing pipeline

software_reference: String

The software used

params: ParamList

Controlled vocabulary and user parameters