pub struct ScanSettings {
pub id: String,
pub source_file_refs: Vec<String>,
pub targets: Vec<Vec<Param>>,
pub params: Vec<Param>,
}Expand description
Description of the acquisition settings of the instrument prior to the start of the run
Fields
id: StringA unique identifier
source_file_refs: Vec<String>List with the source files containing the acquisition settings
targets: Vec<Vec<Param>>Target list (or ‘inclusion list’) configured prior to the run
params: Vec<Param>The controlled vocabulary and user parameters of the settings
Implementations