SourceFile

Struct SourceFile 

pub struct SourceFile {
    pub name: String,
    pub location: String,
    pub id: String,
    pub file_format: Option<Param>,
    pub id_format: Option<Param>,
    pub params: ParamList,
}
Description of a source file, including location and type.

This is usually another mass spectrometry data file. For some vendor raw formats that are directories, there can be many files. See https://peptideatlas.org/tmp/mzML1.1.0.html#sourceFile.

Fields

name: String

The name of the source file without any path or location information

location: String

The URI-formatted location where the file was retrieved.

id: String

A unique identifier for this source file

file_format: Option<Param>

The MassSpectrometerFileFormatTerm-defined parameter for this file

id_format: Option<Param>

The NativeSpectrumIdentifierFormatTerm-defined parameter for this file

params: ParamList

The rest of the parameters for this file.

Implementations

Source

impl SourceFile

pub fn native_id_format(&self) -> Option<NativeSpectrumIDFormat>

Convert SourceFile::id_format into a NativeSpectrumIDFormat carrying its own parser machinery, if such a term mapping exists