pub trait MSDataFileMetadata {
Show 18 methods
// Required methods
fn data_processings(&self) -> &Vec<DataProcessing>;
fn instrument_configurations(
&self,
) -> &HashMap<u32, InstrumentConfiguration>;
fn file_description(&self) -> &FileDescription;
fn softwares(&self) -> &Vec<Software>;
fn samples(&self) -> &Vec<Sample>;
fn data_processings_mut(&mut self) -> &mut Vec<DataProcessing>;
fn instrument_configurations_mut(
&mut self,
) -> &mut HashMap<u32, InstrumentConfiguration>;
fn file_description_mut(&mut self) -> &mut FileDescription;
fn softwares_mut(&mut self) -> &mut Vec<Software>;
fn samples_mut(&mut self) -> &mut Vec<Sample>;
// Provided methods
fn scan_settings(&self) -> Option<&Vec<ScanSettings>> { ... }
fn scan_settings_mut(&mut self) -> Option<&mut Vec<ScanSettings>> { ... }
fn copy_metadata_from(&mut self, source: &impl MSDataFileMetadata)
where Self: Sized { ... }
fn spectrum_count_hint(&self) -> Option<u64> { ... }
fn set_spectrum_count_hint(&mut self, _value: Option<u64>) { ... }
fn run_description(&self) -> Option<&MassSpectrometryRun> { ... }
fn run_description_mut(&mut self) -> Option<&mut MassSpectrometryRun> { ... }
fn source_file_name(&self) -> Option<&str> { ... }
}Expand description
Mass spectrometry data files have several facets of descriptive metadata
Required Methods
Sourcefn data_processings(&self) -> &Vec<DataProcessing>
fn data_processings(&self) -> &Vec<DataProcessing>
The series of DataProcessing workflows applied to spectra in
this data file.
Sourcefn instrument_configurations(&self) -> &HashMap<u32, InstrumentConfiguration>
fn instrument_configurations(&self) -> &HashMap<u32, InstrumentConfiguration>
A mapping over different InstrumentConfiguration modes that spectra
were acquired under.
Sourcefn file_description(&self) -> &FileDescription
fn file_description(&self) -> &FileDescription
A description of the contents and the sources for this mass spectrometry data file.
Sourcefn softwares(&self) -> &Vec<Software>
fn softwares(&self) -> &Vec<Software>
The series of Software applied to the data file to apply different
DataProcessing methods.
Sourcefn samples(&self) -> &Vec<Sample>
fn samples(&self) -> &Vec<Sample>
A list of sample descriptions that were measured in this data file if available.
Sourcefn data_processings_mut(&mut self) -> &mut Vec<DataProcessing>
fn data_processings_mut(&mut self) -> &mut Vec<DataProcessing>
Mutably access the DataProcessing list for this data file
Sourcefn instrument_configurations_mut(
&mut self,
) -> &mut HashMap<u32, InstrumentConfiguration>
fn instrument_configurations_mut( &mut self, ) -> &mut HashMap<u32, InstrumentConfiguration>
Mutably access the InstrumentConfiguration mapping for this data file
Sourcefn file_description_mut(&mut self) -> &mut FileDescription
fn file_description_mut(&mut self) -> &mut FileDescription
Mutably access the FileDescription description of the contents and the
sources for this mass spectrometry data file.
Sourcefn softwares_mut(&mut self) -> &mut Vec<Software>
fn softwares_mut(&mut self) -> &mut Vec<Software>
Mutably access the list of Software of this data file.
fn samples_mut(&mut self) -> &mut Vec<Sample>
Provided Methods
Sourcefn scan_settings(&self) -> Option<&Vec<ScanSettings>>
fn scan_settings(&self) -> Option<&Vec<ScanSettings>>
A list of scan settings in ScanSettings pre-configured by the instrument
operator prior to the start of data acquisition.
This information is relatively unstructured and unless manually specified will be absent from most formats.
Sourcefn scan_settings_mut(&mut self) -> Option<&mut Vec<ScanSettings>>
fn scan_settings_mut(&mut self) -> Option<&mut Vec<ScanSettings>>
Mutably access the list of ScanSettings for this dataset. Most formats do not
possess a related concept and will not carry one.
Sourcefn copy_metadata_from(&mut self, source: &impl MSDataFileMetadata)where
Self: Sized,
fn copy_metadata_from(&mut self, source: &impl MSDataFileMetadata)where
Self: Sized,
Copy the metadata from another MSDataFileMetadata implementation into
this one.
Sourcefn spectrum_count_hint(&self) -> Option<u64>
fn spectrum_count_hint(&self) -> Option<u64>
A hint about how many spectra are in this data file
fn set_spectrum_count_hint(&mut self, _value: Option<u64>)
Sourcefn run_description(&self) -> Option<&MassSpectrometryRun>
fn run_description(&self) -> Option<&MassSpectrometryRun>
Access the MassSpectrometryRun metadata record if it is available
Sourcefn run_description_mut(&mut self) -> Option<&mut MassSpectrometryRun>
fn run_description_mut(&mut self) -> Option<&mut MassSpectrometryRun>
Mutably access the MassSpectrometryRun metadata record if it is available
Sourcefn source_file_name(&self) -> Option<&str>
fn source_file_name(&self) -> Option<&str>
Get the name of the primary source file, if available
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<T: MSDataFileMetadata> MSDataFileMetadata for Arc<T>
MSDataFileMetadata may be accessed on std::sync::Arc wrapping types that implement the trait,
but attempting to use the mutable methods will panic if the underlying instance is already shared.
impl<T: MSDataFileMetadata> MSDataFileMetadata for Arc<T>
MSDataFileMetadata may be accessed on std::sync::Arc wrapping types that implement the trait,
but attempting to use the mutable methods will panic if the underlying instance is already shared.