Metadata describing mass spectrometry data files and their contents.
Macros
- cvmap
- delegate_
impl_ metadata_ trait - Delegates the implementation of
MSDataFileMetadatato a member. Passing an extra levelextendedtoken implements the optional methods. - impl_
metadata_ trait - Assumes a field for the non-
Optionfacets of theMSDataFileMetadataimplementation are present. Passing an extra levelextendedtoken implements the optional methods.
Structs
- Component
- A description of a combination of parts that are described as part of an
InstrumentConfiguration. There may be more than one component of the same type in a singel configuration, e.g. a triple-quad instrument can have three separateComponentType::Analyzercomponents. - Data
Processing - Describe a complete data processing method, a series of
ProcessingMethodtransformations through a pipeline ofSoftware. - File
Description - A description of the file data file and its contents
- File
Metadata Config - A helper data structure for implementing
MSDataFileMetadatain a single common implementation. - Instrument
Configuration - A series of mass spectrometer components that together were engaged to acquire a mass spectrum
- Mass
Spectrometry Run - Metadata describing the experiment that does not belong in any other section that covers some default options.
- Native
SpectrumID Format - A text-based schema that defines how native spectrum identifiers are formatted.
- Processing
Method - Describe a data processing method stage tied to a specific piece of
Software - Sample
- A sample that was used to generate a MS dataset
- Scan
Settings - Description of the acquisition settings of the instrument prior to the start of the run
- Software
- A piece of software that was associated with the acquisition, transformation or otherwise processing of mass spectrometry data.
- Software
Type Flags - A bit mask encoding the different kinds of software.
- Source
File - Description of a source file, including location and type.
- Value
Type - A bit mask encoding the different value types a
Paramcan take on, associated with a term.
Enums
- Component
Type - A distinguishing tag describing the part of an instrument a
Componentrefers to - Data
Processing Action - Data
Transformation Action - Detector
Type Term - Dissociation
Energy - Dissociation
Energy Term - Energy for an ion experiencing some form of dissociation
- Dissociation
Method Term - A method used for dissociation or fragmentation.
- Format
Conversion - Inlet
Type Term - Ionization
Type Term - Mass
Analyzer Term - Mass
Spectrometer File Format Term - NativeID
Format Error - Native
Spectrum Identifier Format Term - A text-based schema that defines how native spectrum identifiers are formatted. These patterns are often found in mzML-compatible formats.
- Software
Term - Spectrum
Type - The kinds of spectrum that might be represented
Traits
- MSData
File Metadata - Mass spectrometry data files have several facets of descriptive metadata
Functions
- custom_
software_ name - Create an instance of “custom unreleased software tool” with name
name