pub enum DetectorTypeTerm {
Show 24 variants
DetectorType,
Channeltron,
ConversionDynodeElectronMultiplier,
ConversionDynodePhotomultiplier,
DalyDetector,
ElectronMultiplierTube,
FaradayCup,
FocalPlaneArray,
MicrochannelPlateDetector,
MultiCollector,
Photomultiplier,
ElectronMultiplier,
ArrayDetector,
ConversionDynode,
Dynode,
FocalPlaneCollector,
IonToPhotonDetector,
PointCollector,
PostaccelerationDetector,
PhotodiodeArrayDetector,
InductiveDetector,
AcquityUPLCPDA,
AcquityUPLCFLR,
FluorescenceDetector,
}Variants
DetectorType
detector type - Type of detector used in the mass spectrometer.
Channeltron
channeltron - A horn-shaped (or cone-shaped) continuous dynode particle multiplier. The ion strikes the inner surface of the device and induces the production of secondary electrons that in turn impinge on the inner surfaces to produce more secondary electrons. This avalanche effect produces an increase in signal in the final measured current pulse.
ConversionDynodeElectronMultiplier
conversion dynode electron multiplier - A surface that is held at high potential so that ions striking the surface produce electrons that are subsequently detected.
ConversionDynodePhotomultiplier
conversion dynode photomultiplier - A detector in which ions strike a conversion dynode to produce electrons that in turn generate photons through a phosphorescent screen that are detected by a photomultiplier.
DalyDetector
daly detector - Detector consisting of a conversion dynode, scintillator and photomultiplier. The metal knob at high potential emits secondary electrons when ions impinge on the surface. The secondary electrons are accelerated onto the scintillator that produces light that is then detected by the photomultiplier detector.
ElectronMultiplierTube
electron multiplier tube - A device to amplify the current of a beam or packet of charged particles or photons by incidence upon the surface of an electrode to produce secondary electrons.
FaradayCup
faraday cup - A conducting cup or chamber that intercepts a charged particle beam and is electrically connected to a current measuring device.
FocalPlaneArray
focal plane array - An array of detectors for spatially disperse ion beams in which all ions simultaneously impinge on the detector plane.
MicrochannelPlateDetector
microchannel plate detector - A thin plate that contains a closely spaced array of channels that each act as a continuous dynode particle multiplier. A charged particle, fast neutral particle, or photon striking the plate causes a cascade of secondary electrons that ultimately exits the opposite side of the plate.
MultiCollector
multi-collector - A detector system commonly used in inductively coupled plasma mass spectrometers.
Photomultiplier
photomultiplier - A detector for conversion of the ion/electron signal into photon(s) which are then amplified and detected.
ElectronMultiplier
electron multiplier - A device to amplify the current of a beam or packet of charged particles or photons by incidence upon the surface of an electrode to produce secondary electrons. The secondary electrons are then accelerated to other electrodes or parts of a continuous electrode to produce further secondary electrons.
ArrayDetector
array detector - Detector comprising several ion collection elements, arranged in a line or grid where each element is an individual detector.
ConversionDynode
conversion dynode - A surface that is held at high potential such that ions striking the surface produce electrons that are subsequently detected.
Dynode
dynode - One of a series of electrodes in a photomultiplier tube. Such an arrangement is able to amplify the current emitted by the photocathode.
FocalPlaneCollector
focal plane collector - A detector for spatially disperse ion beams in which all ions simultaneously impinge on the detector plane.
IonToPhotonDetector
ion-to-photon detector - A detector in which ions strike a conversion dynode to produce electrons that in turn strike a phosphor and the resulting photons are detected by a photomultiplier.
PointCollector
point collector - A detector in which the ion beam is focused onto a point and the individual ions arrive sequentially.
PostaccelerationDetector
postacceleration detector - A detector in which the charged particles are accelerated to a high velocity and impinge on a conversion dynode, emitting secondary electrons. The electrons are accelerated onto a phosphor screen, which emits photons that are in turn detected using a photomultiplier or other photon detector.
PhotodiodeArrayDetector
photodiode array detector - An array detector used to record spectra in the ultraviolet and visible region of light.
InductiveDetector
inductive detector - Inductive detector.
AcquityUPLCPDA
Acquity UPLC PDA - Acquity UPLC Photodiode Array Detector.
AcquityUPLCFLR
Acquity UPLC FLR - Acquity UPLC Fluorescence Detector.
FluorescenceDetector
fluorescence detector - A detector using a fluorescent signal after excitation with light.
Implementations
Sourceimpl DetectorTypeTerm
These methods are part of the controlled vocabulary mapping
impl DetectorTypeTerm
These methods are part of the controlled vocabulary mapping
Sourcepub const fn accession(&self) -> AccessionIntCode
pub const fn accession(&self) -> AccessionIntCode
Retrieve the accession number for this term, independent of its controlled vocabulary
Sourcepub const fn controlled_vocabulary(&self) -> ControlledVocabulary
pub const fn controlled_vocabulary(&self) -> ControlledVocabulary
Retrieve the controlled vocabulary this term belongs to
Sourcepub const fn name(&self) -> &'static str
pub const fn name(&self) -> &'static str
Retrieve the plain text human readable name for this term
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Attempt to map a string by name to retrieve one of the terms from this set.
If no match is found, None is returned.
Sourcepub const fn from_accession(accession: AccessionIntCode) -> Option<Self>
pub const fn from_accession(accession: AccessionIntCode) -> Option<Self>
Attempt to map the numeric accession number to retrieve one of the terms from this set.
If no match is found, None is returned.
Sourcepub const fn to_param(self) -> ParamCow<'static>
pub const fn to_param(self) -> ParamCow<'static>
Convert this term into a ParamCow without a value.
Sourcepub const fn from_curie(curie: &CURIE) -> Option<Self>
pub const fn from_curie(curie: &CURIE) -> Option<Self>
Sourcepub const fn from_param(p: &ParamCow<'static>) -> Option<Self>
pub const fn from_param(p: &ParamCow<'static>) -> Option<Self>