pub enum DissociationEnergyTerm {
CollisionEnergy(f32),
NormalizedCollisionEnergy(f32),
CollisionEnergyRampStart(f32),
CollisionEnergyRampEnd(f32),
PercentCollisionEnergyRampStart(f32),
PercentCollisionEnergyRampEnd(f32),
SupplementalCollisionEnergy(f32),
ElectronBeamEnergy(f32),
}Expand description
Energy for an ion experiencing some form of dissociation
Variants
CollisionEnergy(f32)
collision energy - Energy for an ion experiencing collision with a stationary gas particle resulting in dissociation of the ion.
NormalizedCollisionEnergy(f32)
normalized collision energy - Instrument setting, expressed in percent, for adjusting collisional energies of ions in an effort to provide equivalent excitation of all ions.
CollisionEnergyRampStart(f32)
collision energy ramp start - Collision energy at the start of the collision energy ramp.
CollisionEnergyRampEnd(f32)
collision energy ramp end - Collision energy at the end of the collision energy ramp.
PercentCollisionEnergyRampStart(f32)
percent collision energy ramp start - Collision energy at the start of the collision energy ramp in percent, normalized to the mass of the ion.
PercentCollisionEnergyRampEnd(f32)
percent collision energy ramp end - Collision energy at the end of the collision energy ramp in percent, normalized to the mass of the ion.
SupplementalCollisionEnergy(f32)
supplemental collision energy - Energy for an ion experiencing supplemental collision with a stationary gas particle resulting in dissociation of the ion.
ElectronBeamEnergy(f32)
electron beam energy - The kinetic energy of the electron beam used in dissociation methods induced by a free electron beam, such as electron-capture dissociation (ECD), electron-detachment dissociation (EDD), and electron-activated dissociation (EAD).
Implementations
Sourceimpl DissociationEnergyTerm
These methods are part of the controlled vocabulary mapping
impl DissociationEnergyTerm
These methods are part of the controlled vocabulary mapping
Sourcepub const fn accession(&self) -> AccessionIntCode
pub const fn accession(&self) -> AccessionIntCode
Retrieve the accession number for this term, independent of its controlled vocabulary
Sourcepub const fn controlled_vocabulary(&self) -> ControlledVocabulary
pub const fn controlled_vocabulary(&self) -> ControlledVocabulary
Retrieve the controlled vocabulary this term belongs to
Sourcepub const fn name(&self) -> &'static str
pub const fn name(&self) -> &'static str
Retrieve the plain text human readable name for this term
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Attempt to map a string by name to retrieve one of the terms from this set.
If no match is found, None is returned.
Sourcepub const fn from_accession(
accession: AccessionIntCode,
value: f32,
) -> Option<Self>
pub const fn from_accession( accession: AccessionIntCode, value: f32, ) -> Option<Self>
Attempt to map the numeric accession number to retrieve one of the terms from this set.
If no match is found, None is returned.
Sourcepub const fn to_param(self) -> ParamCow<'static>
pub const fn to_param(self) -> ParamCow<'static>
Convert this term into a ParamCow without a value.
Sourcepub const fn to_param_value(self, value: ValueRef<'static>) -> ParamCow<'static>
pub const fn to_param_value(self, value: ValueRef<'static>) -> ParamCow<'static>
Convert this term into a ParamCow a specific boxed value.
Sourcepub fn from_curie(curie: &CURIE, value: f32) -> Option<Self>
pub fn from_curie(curie: &CURIE, value: f32) -> Option<Self>
Sourcepub fn from_param(p: &ParamCow<'static>) -> Option<Self>
pub fn from_param(p: &ParamCow<'static>) -> Option<Self>
Sourceimpl DissociationEnergyTerm
impl DissociationEnergyTerm
Sourcepub const fn is_supplemental(&self) -> bool
pub const fn is_supplemental(&self) -> bool
Is the collision energy supplemental to another dissociation method?
Sourcepub const fn is_ramp_start(&self) -> bool
pub const fn is_ramp_start(&self) -> bool
Is this the start of an energy ramp?
Sourcepub const fn is_ramp_end(&self) -> bool
pub const fn is_ramp_end(&self) -> bool
Is this the end of an energy ramp?
Sourcepub fn energy_mut(&mut self) -> &mut f32
pub fn energy_mut(&mut self) -> &mut f32
Get a mutable reference to the energy in the term