pub enum DissociationMethodTerm {
Show 23 variants
DissociationMethod,
CollisionInducedDissociation,
PlasmaDesorption,
PostSourceDecay,
SurfaceInducedDissociation,
BlackbodyInfraredRadiativeDissociation,
ElectronCaptureDissociation,
InfraredMultiphotonDissociation,
SustainedOffResonanceIrradiation,
BeamTypeCollisionInducedDissociation,
LowEnergyCollisionInducedDissociation,
Photodissociation,
ElectronTransferDissociation,
PulsedQDissociation,
InSourceCollisionInducedDissociation,
LIFT,
TrapTypeCollisionInducedDissociation,
HigherEnergyBeamTypeCollisionInducedDissociation,
SupplementalBeamTypeCollisionInducedDissociation,
SupplementalCollisionInducedDissociation,
UltravioletPhotodissociation,
NegativeElectronTransferDissociation,
ElectronActivatedDissociation,
}Expand description
A method used for dissociation or fragmentation.
Variants
DissociationMethod
dissociation method - Fragmentation method used for dissociation or fragmentation.
CollisionInducedDissociation
collision-induced dissociation - The dissociation of an ion after collisional excitation. The term collisional-activated dissociation is not recommended.
PlasmaDesorption
plasma desorption - The ionization of material in a solid sample by bombarding it with ionic or neutral atoms formed as a result of the fission of a suitable nuclide, typically 252Cf. Synonymous with fission fragment ionization.
PostSourceDecay
post-source decay - A technique specific to reflectron time-of-flight mass spectrometers where product ions of metastable transitions or collision-induced dissociations generated in the drift tube prior to entering the reflectron are m/z separated to yield product ion spectra.
SurfaceInducedDissociation
surface-induced dissociation - Fragmentation that results from the collision of an ion with a surface.
BlackbodyInfraredRadiativeDissociation
blackbody infrared radiative dissociation - A special case of infrared multiphoton dissociation wherein excitation of the reactant ion is caused by absorption of infrared photons radiating from heated blackbody surroundings, which are usually the walls of a vacuum chamber. See also infrared multiphoton dissociation.
ElectronCaptureDissociation
electron capture dissociation - A process in which a multiply protonated molecules interacts with a low energy electrons. Capture of the electron leads the liberation of energy and a reduction in charge state of the ion with the production of the (M + nH) (n-1)+ odd electron ion, which readily fragments.
InfraredMultiphotonDissociation
infrared multiphoton dissociation - Multiphoton ionization where the reactant ion dissociates as a result of the absorption of multiple infrared photons.
SustainedOffResonanceIrradiation
sustained off-resonance irradiation - A technique associated with Fourier transform ion cyclotron resonance (FT-ICR) mass spectrometry to carry out ion/neutral reactions such as low-energy collision-induced dissociation. A radio-frequency electric field of slightly off-resonance to the cyclotron frequency of the reactant ion cyclically accelerates and decelerates the reactant ion that is confined in the Penning ion trap. The ion’s orbit does not exceed the dimensions of ion trap while the ion undergoes an ion/neutral species process that produces a high average translational energy for an extended time.
BeamTypeCollisionInducedDissociation
beam-type collision-induced dissociation - A collision-induced dissociation process that occurs in a beam-type collision cell.
LowEnergyCollisionInducedDissociation
low-energy collision-induced dissociation - A collision-induced dissociation process wherein the precursor ion has the translational energy lower than approximately 1000 eV. This process typically requires multiple collisions and the collisional excitation is cumulative.
Photodissociation
photodissociation - A process wherein the reactant ion is dissociated as a result of absorption of one or more photons.
ElectronTransferDissociation
electron transfer dissociation - A process to fragment ions in a mass spectrometer by inducing fragmentation of cations (e.g. peptides or proteins) by transferring electrons from radical-anions.
PulsedQDissociation
pulsed q dissociation - A process that involves precursor ion activation at high Q, a time delay to allow the precursor to fragment, then a rapid pulse to low Q where all fragment ions are trapped. The product ions can then be scanned out of the ion trap and detected.
InSourceCollisionInducedDissociation
in-source collision-induced dissociation - The dissociation of an ion as a result of collisional excitation during ion transfer from an atmospheric pressure ion source and the mass spectrometer vacuum.
LIFT
LIFT - A Bruker’s proprietary technique where molecular ions are initially accelerated at lower energy, then collide with inert gas in a collision cell that is then ‘lifted’ to high potential. The use of inert gas is optional, as it could lift also fragments provided by LID.
TrapTypeCollisionInducedDissociation
trap-type collision-induced dissociation - A collision-induced dissociation process that occurs in a trap-type collision cell.
HigherEnergyBeamTypeCollisionInducedDissociation
higher energy beam-type collision-induced dissociation - A collision-induced dissociation process wherein the projectile ion has the translational energy higher than approximately 1000 eV.
SupplementalBeamTypeCollisionInducedDissociation
supplemental beam-type collision-induced dissociation - A supplemental collision-induced dissociation process that occurs in a beam-type collision cell in addition to another primary type of dissociation.
SupplementalCollisionInducedDissociation
supplemental collision-induced dissociation - The dissociation of an ion after supplemental collisional excitation.
UltravioletPhotodissociation
ultraviolet photodissociation - Multiphoton ionization where the reactant ion dissociates as a result of the absorption of multiple UV photons.
NegativeElectronTransferDissociation
negative electron transfer dissociation - A process to fragment ions in a mass spectrometer by inducing fragmentation of anions (e.g. peptides or proteins) by transferring electrons to a radical-cation.
ElectronActivatedDissociation
electron activated dissociation - A process to fragment ions in a high intensity electron beam which results in a dissociation of various analytes ranging from singly charged small molecules to multiply protonated proteins.
Implementations
Sourceimpl DissociationMethodTerm
These methods are part of the controlled vocabulary mapping
impl DissociationMethodTerm
These methods are part of the controlled vocabulary mapping
Sourcepub const fn accession(&self) -> AccessionIntCode
pub const fn accession(&self) -> AccessionIntCode
Retrieve the accession number for this term, independent of its controlled vocabulary
Sourcepub const fn controlled_vocabulary(&self) -> ControlledVocabulary
pub const fn controlled_vocabulary(&self) -> ControlledVocabulary
Retrieve the controlled vocabulary this term belongs to
Sourcepub const fn name(&self) -> &'static str
pub const fn name(&self) -> &'static str
Retrieve the plain text human readable name for this term
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Attempt to map a string by name to retrieve one of the terms from this set.
If no match is found, None is returned.
Sourcepub const fn from_accession(accession: AccessionIntCode) -> Option<Self>
pub const fn from_accession(accession: AccessionIntCode) -> Option<Self>
Attempt to map the numeric accession number to retrieve one of the terms from this set.
If no match is found, None is returned.
Sourcepub const fn to_param(self) -> ParamCow<'static>
pub const fn to_param(self) -> ParamCow<'static>
Convert this term into a ParamCow without a value.
Sourcepub const fn from_curie(curie: &CURIE) -> Option<Self>
pub const fn from_curie(curie: &CURIE) -> Option<Self>
Sourcepub const fn from_param(p: &ParamCow<'static>) -> Option<Self>
pub const fn from_param(p: &ParamCow<'static>) -> Option<Self>
Sourceimpl DissociationMethodTerm
impl DissociationMethodTerm
pub fn is_electronic(&self) -> bool
pub fn is_collisional(&self) -> bool