pub enum InletTypeTerm {
Show 20 variants
InletType,
ContinuousFlowFastAtomBombardment,
DirectInlet,
ElectrosprayInlet,
FlowInjectionAnalysis,
InductivelyCoupledPlasma,
Infusion,
JetSeparator,
MembraneSeparator,
MovingBelt,
MovingWire,
OpenSplit,
ParticleBeam,
Reservoir,
Septum,
ThermosprayInlet,
DirectInsertionProbe,
DirectLiquidIntroduction,
MembraneInlet,
NanosprayInlet,
}Variants
InletType
inlet type - The nature of the sample inlet.
ContinuousFlowFastAtomBombardment
continuous flow fast atom bombardment - Fast atom bombardment ionization in which the analyte in solution is entrained in a flowing liquid matrix.
DirectInlet
direct inlet - The sample is directly inserted into the ion source, usually on the end of a heatable probe.
ElectrosprayInlet
electrospray inlet - Inlet used for introducing the liquid sample into an electrospray ionization source.
FlowInjectionAnalysis
flow injection analysis - A sample introduction method in which a discrete sample aliquot is injected into a continuous carrier solvent stream and transported to the ionization source without separation, producing a transient analytical signal.
InductivelyCoupledPlasma
inductively coupled plasma - A gas discharge ion source in which the energy to the plasma is supplied by electromagnetic induction.
Infusion
infusion - A sample introduction method in which a sample solution is continuously delivered to the ionization source at a constant flow rate without separation.
JetSeparator
jet separator - A device that separates carrier gas from gaseous analyte molecules on the basis of diffusivity.
MembraneSeparator
membrane separator - A device to separate carrier molecules from analyte molecules on the basis of ease of diffusion across a semipermeable membrane.
MovingBelt
moving belt - Continuous moving surface in the form of a belt which passes through an ion source carrying analyte molecules.
MovingWire
moving wire - Continuous moving surface in the form of a wire which passes through an ion source carrying analyte molecules.
OpenSplit
open split - A division of flowing stream of liquid into two streams.
ParticleBeam
particle beam - Method for generating ions from a solution of an analyte.
Reservoir
reservoir - A sample inlet method involving a reservoir.
Septum
septum - A disc composed of a flexible material that seals the entrance to the reservoir. Can also be entrance to the vacuum chamber.
ThermosprayInlet
thermospray inlet - A method for generating gas phase ions from a solution of an analyte by rapid heating of the sample.
DirectInsertionProbe
direct insertion probe - A device for introducing a solid or liquid sample into a mass spectrometer ion source for desorption ionization.
DirectLiquidIntroduction
direct liquid introduction - A legacy liquid chromatography-mass spectrometry interface in which a minor fraction of the eluate flow is split and introduced through a narrow orifice or diaphragm directly into the ion source, with solvent-mediated chemical ionization. This interface was largely superseded by atmospheric pressure ionization methods.
MembraneInlet
membrane inlet - A semi-permeable membrane separator that permits the passage of gas sample directly to the mass spectrometer ion source.
NanosprayInlet
nanospray inlet - Nanospray Inlet.
Implementations
Sourceimpl InletTypeTerm
These methods are part of the controlled vocabulary mapping
impl InletTypeTerm
These methods are part of the controlled vocabulary mapping
Sourcepub const fn accession(&self) -> AccessionIntCode
pub const fn accession(&self) -> AccessionIntCode
Retrieve the accession number for this term, independent of its controlled vocabulary
Sourcepub const fn controlled_vocabulary(&self) -> ControlledVocabulary
pub const fn controlled_vocabulary(&self) -> ControlledVocabulary
Retrieve the controlled vocabulary this term belongs to
Sourcepub const fn name(&self) -> &'static str
pub const fn name(&self) -> &'static str
Retrieve the plain text human readable name for this term
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Attempt to map a string by name to retrieve one of the terms from this set.
If no match is found, None is returned.
Sourcepub const fn from_accession(accession: AccessionIntCode) -> Option<Self>
pub const fn from_accession(accession: AccessionIntCode) -> Option<Self>
Attempt to map the numeric accession number to retrieve one of the terms from this set.
If no match is found, None is returned.
Sourcepub const fn to_param(self) -> ParamCow<'static>
pub const fn to_param(self) -> ParamCow<'static>
Convert this term into a ParamCow without a value.
Sourcepub const fn from_curie(curie: &CURIE) -> Option<Self>
pub const fn from_curie(curie: &CURIE) -> Option<Self>
Sourcepub const fn from_param(p: &ParamCow<'static>) -> Option<Self>
pub const fn from_param(p: &ParamCow<'static>) -> Option<Self>