pub enum IonizationTypeTerm {
Show 54 variants
IonizationType,
AtmosphericPressureChemicalIonization,
ChemicalIonization,
ElectrosprayIonization,
FastAtomBombardmentIonization,
MatrixAssistedLaserDesorptionIonization,
MultiphotonIonization,
AtmosphericPressureMatrixAssistedLaserDesorptionIonization,
AtmosphericPressureIonization,
DesorptionIonization,
FlowingAfterglow,
FieldDesorption,
FieldIonization,
GlowDischargeIonization,
NegativeIonChemicalIonization,
NeutralizationReionizationMassSpectrometry,
Photoionization,
PyrolysisMassSpectrometry,
ResonanceEnhancedMultiphotonIonization,
SurfaceEnhancedLaserDesorptionIonization,
SurfaceEnhancedNeatDesorption,
AdiabaticIonization,
AssociativeIonization,
AtmosphericPressurePhotoionization,
Autodetachment,
Autoionization,
ChargeExchangeIonization,
ChemiIonization,
DesorptionIonizationOnSilicon,
DissociativeIonization,
ElectronIonization,
LaserDesorptionIonization,
LiquidSecondaryIonization,
Microelectrospray,
Nanoelectrospray,
PenningIonization,
PlasmaDesorptionIonization,
SecondaryIonization,
SoftIonization,
SparkIonization,
SurfaceAssistedLaserDesorptionIonization,
SurfaceIonization,
ThermalIonization,
VerticalIonization,
FastIonBombardment,
DesorptionElectrosprayIonization,
PaperSprayIonization,
ProtonTransferReaction,
ProtonTransferChargeReduction,
SecondaryElectrosprayIonization,
ArgonGasClusterIonBeam,
BismuthLiquidMetalIonGun,
GasClusterIonBeam,
LiquidMetalIonGun,
}Variants
IonizationType
ionization type - The method by which gas phase ions are generated from the sample.
AtmosphericPressureChemicalIonization
atmospheric pressure chemical ionization - Chemical ionization that takes place at atmospheric pressure as opposed to the reduced pressure is normally used for chemical ionization.
ChemicalIonization
chemical ionization - The formation of a new ion by the reaction of a neutral species with an ion. The process may involve transfer of an electron, a proton or other charged species between the reactants. When a positive ion results from chemical ionization the term may be used without qualification. When a negative ion results the term negative ion chemical ionization should be used. Note that this term is not synonymous with chemi-ionization.
ElectrosprayIonization
electrospray ionization - A process in which ionized species in the gas phase are produced from an analyte-containing solution via highly charged fine droplets, by means of spraying the solution from a narrow-bore needle tip at atmospheric pressure in the presence of a high electric field. When a pressurized gas is used to aid in the formation of a stable spray, the term pneumatically assisted electrospray ionization is used. The term ion spray is not recommended.
FastAtomBombardmentIonization
fast atom bombardment ionization - The ionization of any species by the interaction of a focused beam of neutral atoms having a translational energy of several thousand eV with a sample that is typically dissolved in a solvent matrix. See also secondary ionization.
MatrixAssistedLaserDesorptionIonization
matrix-assisted laser desorption ionization - The formation of gas-phase ions from molecules that are present in a solid or solvent matrix that is irradiated with a pulsed laser. See also laser desorption/ionization.
MultiphotonIonization
multiphoton ionization - Photoionization of an atom or molecule in which in two or more photons are absorbed.
AtmosphericPressureMatrixAssistedLaserDesorptionIonization
atmospheric pressure matrix-assisted laser desorption ionization - Matrix-assisted laser desorption ionization in which the sample target is at atmospheric pressure and the ions formed by the pulsed laser are sampled through a small aperture into the mass spectrometer.
AtmosphericPressureIonization
atmospheric pressure ionization - Any ionization process in which ions are formed in the gas phase at atmospheric pressure.
DesorptionIonization
desorption ionization - The formation of ions from a solid or liquid material after the rapid vaporization of that sample.
FlowingAfterglow
flowing afterglow - An ion source immersed in a flow of helium or other inert buffer gas that carries the ions through a meter-long reactor at pressures around 100 Pa.
FieldDesorption
field desorption - The formation of gas-phase ions from a material deposited on a solid surface in the presence of a high electric field. Because this process may encompass ionization by field ionization or other mechanisms, it is not recommended as a synonym for field desorption ionization.
FieldIonization
field ionization - The removal of electrons from any species by interaction with a high electric field.
GlowDischargeIonization
glow discharge ionization - The formation of ions in the gas phase and from solid samples at the cathode by application of a voltage to a low pressure gas.
NegativeIonChemicalIonization
Negative Ion chemical ionization - Chemical ionization that results in the formation of negative ions.
NeutralizationReionizationMassSpectrometry
neutralization reionization mass spectrometry - With this technique, m/z selected ions form neutrals by charge transfer to a collision gas or by dissociation. The neutrals are separated from the remaining ions and ionized in collisions with a second gas. This method is used to investigate reaction intermediates and other unstable species.
Photoionization
photoionization - The ionization of an atom or molecule by a photon, written M + h? ? M^+ + e. The term photon impact is not recommended.
PyrolysisMassSpectrometry
pyrolysis mass spectrometry - A mass spectrometry technique in which the sample is heated to the point of decomposition and the gaseous decomposition products are introduced into the ion source.
ResonanceEnhancedMultiphotonIonization
resonance enhanced multiphoton ionization - Multiphoton ionization in which the ionization cross section is significantly enhanced because the energy of the incident photons is resonant with an intermediate excited state of the neutral species.
SurfaceEnhancedLaserDesorptionIonization
surface enhanced laser desorption ionization - The formation of ionized species in the gas phase from analytes deposited on a particular surface substrate which is irradiated with a laser beam of which wavelength is absorbed by the surface. See also desorption/ionization on silicon and laser desorption/ionization.
SurfaceEnhancedNeatDesorption
surface enhanced neat desorption - Matrix-assisted laser desorption ionization in which the matrix is covalently linked to the target surface.
AdiabaticIonization
adiabatic ionization - A process whereby an electron is removed from an atom, ion, or molecule to produce an ion in its lowest energy state.
AssociativeIonization
associative ionization - An ionization process in which two excited atoms or molecules react to form a single positive ion and an electron.
AtmosphericPressurePhotoionization
atmospheric pressure photoionization - Atmospheric pressure chemical ionization in which the reactant ions are generated by photo-ionization.
Autodetachment
autodetachment - The formation of a neutral when a negative ion in a discrete state with an energy greater than the detachment threshold loses an electron spontaneously without further interaction with an energy source.
Autoionization
autoionization - The formation of an ion when an atom or molecule in a discrete state with an energy greater than the ionization threshold loses an electron spontaneously without further interaction with an energy source.
ChargeExchangeIonization
charge exchange ionization - The interaction of an ion with an atom or molecule in which the charge on the ion is transferred to the neutral without the dissociation of either. Synonymous with charge transfer ionization.
ChemiIonization
chemi-ionization - The reaction of a neutral molecule with an internally excited molecule to form an ion. Note that this term is not synonymous with chemical ionization.
DesorptionIonizationOnSilicon
desorption/ionization on silicon - The formation of ions by laser desorption ionization of a sample deposited on a porous silicon surface.
DissociativeIonization
dissociative ionization - The reaction of a gas-phase molecule that results in its decomposition to form products, one of which is an ion.
ElectronIonization
electron ionization - The ionization of an atom or molecule by electrons that are typically accelerated to energies between 50 and 150 eV. Usually 70 eV electrons are used to produce positive ions. The term ‘electron impact’ is not recommended.
LaserDesorptionIonization
laser desorption ionization - The formation of gas-phase ions by the interaction of a pulsed laser with a solid or liquid material.
LiquidSecondaryIonization
liquid secondary ionization - The ionization of any species by the interaction of a focused beam of ions with a sample that is dissolved in a solvent matrix. See also fast atom bombardment and secondary ionization.
Microelectrospray
microelectrospray - Electrospray ionization at a solvent flow rate of 300-800 nL/min where the flow is a result of a mechanical pump. See nanoelectrospray.
Nanoelectrospray
nanoelectrospray - Electrospray ionization at a flow rate less than ~25 nL/min. Nanoelectrospray is synonymous with nanospray. The flow is dependent on the potential on the tip of the electrospray needle and/or a gas pressure to push the sample through the needle. See also electrospray ionization and microelectrospray.
PenningIonization
penning ionization - Ionization that occurs through the interaction of two or more neutral gaseous species, at least one of which is internally excited.
PlasmaDesorptionIonization
plasma desorption ionization - The ionization of material in a solid sample by bombarding it with ionic or neutral atoms formed as a result of the fission of a suitable nuclide, typically 252Cf. Synonymous with fission fragment ionization.
SecondaryIonization
secondary ionization - The process in which ions are ejected from a sample surface as a result of bombardment by a primary beam of atoms or ions.
SoftIonization
soft ionization - The formation of gas-phase ions without extensive fragmentation.
SparkIonization
spark ionization - The formation of ions from a solid material by an intermittent electrical discharge.
SurfaceAssistedLaserDesorptionIonization
surface-assisted laser desorption ionization - The formation of gas-phase ions from molecules that are deposited on a particular surface substrate that is irradiated with a pulsed laser. See also matrix-assisted laser desorption ionization.
SurfaceIonization
surface ionization - The ionization of a neutral species when it interacts with a solid surface with an appropriate work function and temperature.
ThermalIonization
thermal ionization - The ionization of a neutral species through contact with a high temperature surface.
VerticalIonization
vertical ionization - A process in which an electron is removed from or added to a molecule without a change in the positions of the atoms. The resulting ion is typically in an excited vibrational state.
FastIonBombardment
fast ion bombardment - The ionization of any species by the interaction of a focused beam of ions having a translational energy of several thousand eV with a solid sample.
DesorptionElectrosprayIonization
desorption electrospray ionization - Combination of electrospray and desorption ionization method that ionizes gases, liquids and solids in open air under atmospheric pressure.
PaperSprayIonization
paper spray ionization - The ionization of analytes from a piece of paper by applying a solvent and voltage.
ProtonTransferReaction
proton transfer reaction - Process to transfer a proton from a hydronium ion (H3O+) to neutral analyte, leading to a protonated analyte, which typically does not lead to fragmentation.
ProtonTransferChargeReduction
proton transfer charge reduction - Process to transfer one or more protons from a multiply charged cation (peptide or protein ion) to a proton acceptor anion or neutral basic compound, thereby reducing the charge of the original analyte.
SecondaryElectrosprayIonization
secondary electrospray ionization - Secondary electrospray ionization (SESI) is an atmospheric pressure ionization (API) technique that uses a primary nano-electrospray plume of solvent ions to ionize neutral gaseous molecules in the gas phase via efficient proton transfer reactions. Operating at atmospheric pressure, SESI allows for the sensitive and real-time detection of volatile organic compounds (VOCs) and vapors with minimal sample preparation, making it ideal for applications like breath analysis and environmental monitoring.
ArgonGasClusterIonBeam
argon gas cluster ion beam - Argon gas cluster ion beam (Ar GCIB) bombardment uses a focused beam of large argon cluster ions, typically [Ar500]+ to [Ar10000]+, accelerated to high energies to sputter and generate secondary ions from a surface, enabling molecular depth profiling and imaging of organic and biological materials with reduced subsurface damage compared to monatomic ion beams.
BismuthLiquidMetalIonGun
bismuth liquid metal ion gun - Bismuth liquid metal ion gun (Bi LMIG) bombardment uses a focused beam of bismuth ions emitted from a liquid metal ion source to desorb and ionize molecules from a surface. The LMIG source generates a diversity of monomers and clusters, which are filtered prior to the sample in order to select the specific ionisation characteristics.
GasClusterIonBeam
gas cluster ion beam - A gas cluster ion beam (GCIB) is an ion source that generates and accelerates large aggregates of gas atoms or molecules to high energies. The low energy per constituent atom minimizes surface damage and molecular fragmentation, making it highly effective for molecular depth profiling and the analysis of fragile organic and biological materials.
LiquidMetalIonGun
liquid metal ion gun - A liquid metal ion gun (LMIG) is an ion source that extracts and ionizes a thin layer of liquid metal from a fine heated needle using a high-voltage electric field. It produces a high-brightness, tightly focused beam of metal ions or clusters, enabling high-resolution imaging and analysis in Secondary Ion Mass Spectrometry (SIMS).
Implementations
Sourceimpl IonizationTypeTerm
These methods are part of the controlled vocabulary mapping
impl IonizationTypeTerm
These methods are part of the controlled vocabulary mapping
Sourcepub const fn accession(&self) -> AccessionIntCode
pub const fn accession(&self) -> AccessionIntCode
Retrieve the accession number for this term, independent of its controlled vocabulary
Sourcepub const fn controlled_vocabulary(&self) -> ControlledVocabulary
pub const fn controlled_vocabulary(&self) -> ControlledVocabulary
Retrieve the controlled vocabulary this term belongs to
Sourcepub const fn name(&self) -> &'static str
pub const fn name(&self) -> &'static str
Retrieve the plain text human readable name for this term
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Attempt to map a string by name to retrieve one of the terms from this set.
If no match is found, None is returned.
Sourcepub const fn from_accession(accession: AccessionIntCode) -> Option<Self>
pub const fn from_accession(accession: AccessionIntCode) -> Option<Self>
Attempt to map the numeric accession number to retrieve one of the terms from this set.
If no match is found, None is returned.
Sourcepub const fn to_param(self) -> ParamCow<'static>
pub const fn to_param(self) -> ParamCow<'static>
Convert this term into a ParamCow without a value.
Sourcepub const fn from_curie(curie: &CURIE) -> Option<Self>
pub const fn from_curie(curie: &CURIE) -> Option<Self>
Sourcepub const fn from_param(p: &ParamCow<'static>) -> Option<Self>
pub const fn from_param(p: &ParamCow<'static>) -> Option<Self>