pub enum MassAnalyzerTerm {
Show 13 variants
AxialEjectionLinearIonTrap,
FourierTransformIonCyclotronResonance,
MagneticSector,
Quadrupole,
QuadrupoleIonTrap,
RadialEjectionLinearIonTrap,
TimeOfFlight,
ElectrostaticEnergyAnalyzer,
IonTrap,
LinearIonTrap,
MassAnalyzerType,
Orbitrap,
AsymmetricTrackLosslessTimeOfFlightAnalyzer,
}Variants
AxialEjectionLinearIonTrap
axial ejection linear ion trap - A linear ion trap mass analyzer where ions are ejected along the axis of the analyzer.
FourierTransformIonCyclotronResonance
fourier transform ion cyclotron resonance - A device based on the principle of ion cyclotron resonance in which an ion in a magnetic field moves in a circular orbit at a frequency characteristic of its m/z value. Ions are coherently excited to a larger radius orbit using a pulse of radio frequency energy and their image charge is detected on receiver plates as a time domain signal. Fourier transformation of the time domain signal results in a frequency domain signal which is converted to a mass spectrum based in the inverse relationship between frequency and m/z.
MagneticSector
magnetic sector - A device that produces a magnetic field perpendicular to a charged particle beam that deflects the beam to an extent that is proportional to the particle momentum per unit charge. For a monoenergetic beam, the deflection is proportional to m/z.
Quadrupole
quadrupole - A device that consists of four parallel rods whose centers form the corners of a square and whose opposing poles are connected. The voltage applied to the rods is a superposition of a static potential and a sinusoidal radio frequency potential. The motion of an ion in the x and y dimensions is described by the Matthieu equation whose solutions show that ions in a particular m/z range can be transmitted along the z axis.
QuadrupoleIonTrap
quadrupole ion trap - Quadrupole Ion Trap mass analyzer captures the ions in a three dimensional ion trap and then selectively ejects them by varying the RF and DC potentials.
RadialEjectionLinearIonTrap
radial ejection linear ion trap - A linear ion trap mass analyzer where ions are ejected along the radius of the analyzer.
TimeOfFlight
time-of-flight - Instrument that separates ions by m/z in a field-free region after acceleration to a fixed acceleration energy.
ElectrostaticEnergyAnalyzer
electrostatic energy analyzer - A device consisting of conducting parallel plates, concentric cylinders or concentric spheres that separates charged particles according to their kinetic energy by means of an electric field that is constant in time.
IonTrap
ion trap - A device for spatially confining ions using electric and magnetic fields alone or in combination.
LinearIonTrap
linear ion trap - A two dimensional Paul ion trap in which ions are confined in the axial dimension by means of an electric field at the ends of the trap.
MassAnalyzerType
mass analyzer type - Mass analyzer separates the ions according to their mass-to-charge ratio.
Orbitrap
orbitrap - An ion trapping device that consists of an outer barrel-like electrode and a coaxial inner spindle-like electrode that form an electrostatic field with quadro-logarithmic potential distribution. The frequency of harmonic oscillations of the orbitally trapped ions along the axis of the electrostatic field is independent of the ion velocity and is inversely proportional to the square root of m/z so that the trap can be used as a mass analyzer.
AsymmetricTrackLosslessTimeOfFlightAnalyzer
asymmetric track lossless time-of-flight analyzer - A TOF-like mass analyzer with asymmetric ion mirrors to direct ions into transversal asymmetric oscillations and ion foil shapes and maintains ion packet for transmission and resolution.
Implementations
Sourceimpl MassAnalyzerTerm
These methods are part of the controlled vocabulary mapping
impl MassAnalyzerTerm
These methods are part of the controlled vocabulary mapping
Sourcepub const fn accession(&self) -> AccessionIntCode
pub const fn accession(&self) -> AccessionIntCode
Retrieve the accession number for this term, independent of its controlled vocabulary
Sourcepub const fn controlled_vocabulary(&self) -> ControlledVocabulary
pub const fn controlled_vocabulary(&self) -> ControlledVocabulary
Retrieve the controlled vocabulary this term belongs to
Sourcepub const fn name(&self) -> &'static str
pub const fn name(&self) -> &'static str
Retrieve the plain text human readable name for this term
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Attempt to map a string by name to retrieve one of the terms from this set.
If no match is found, None is returned.
Sourcepub const fn from_accession(accession: AccessionIntCode) -> Option<Self>
pub const fn from_accession(accession: AccessionIntCode) -> Option<Self>
Attempt to map the numeric accession number to retrieve one of the terms from this set.
If no match is found, None is returned.
Sourcepub const fn to_param(self) -> ParamCow<'static>
pub const fn to_param(self) -> ParamCow<'static>
Convert this term into a ParamCow without a value.
Sourcepub const fn from_curie(curie: &CURIE) -> Option<Self>
pub const fn from_curie(curie: &CURIE) -> Option<Self>
Sourcepub const fn from_param(p: &ParamCow<'static>) -> Option<Self>
pub const fn from_param(p: &ParamCow<'static>) -> Option<Self>